@@ -66,7 +66,7 @@ END
     def testObjectTypeDescription(self):
         self.assertEqual(
             self.ctx['testObjectType'].getDescription(),
-            'Test object\n',
+            'Test object',
             'bad DESCRIPTION'
         )
 
@@ -87,7 +87,7 @@ END
     def testObjectTypeMaxAccess(self):
         self.assertEqual(
             self.ctx['testObjectType'].getMaxAccess(),
-            'accessible-for-notify',
+            'accessiblefornotify',
             'bad MAX-ACCESS'
         )
 
@@ -217,7 +217,6 @@ END
 
         exec(codeobj, self.ctx, self.ctx)
 
-    # TODO: pyasn1 does not like OctetString.defaultValue
     def testObjectTypeSyntax(self):
         self.assertEqual(
             self.ctx['testObjectType'].getSyntax(), str2octs('test value'),
@@ -640,15 +639,9 @@ END
         exec(codeobj, self.ctx, self.ctx)
 
     def testObjectTypeTableRowAugmention(self):
-        # TODO: provide getAugmentation() method
-        try:
-            augmentingRows = self.ctx['testEntry'].augmentingRows
-
-        except AttributeError:
-            augmentingRows = self.ctx['testEntry']._augmentingRows
-
+        # XXX provide getAugmentation() method
         self.assertEqual(
-            list(augmentingRows)[0],
+            list(self.ctx['testEntry'].augmentingRows.keys())[0],
             ('TEST-MIB', 'testEntryExt'),
             'bad AUGMENTS table clause'
         )
